// https://nuxt.com/docs/api/configuration/nuxt-config
export default defineNuxtConfig({
  compatibilityDate: '2024-11-01',
  devtools: { enabled: false },
  future: {
    compatibilityVersion: 4,
  },

  nitro: {
    prerender: {
      routes: [
        '/',
        '/imprint',
        '/privacy',
      ]
    }
  },

  app: {
    pageTransition: {
      name: 'page',
      mode: 'out-in',
    },
    head: {
      htmlAttrs: { lang: 'de' },
      link: [
        { rel: 'preload', as: 'image', href: '/img/propapier.svg', type: 'image/svg+xml' },
        { rel: 'icon', type: 'image/x-icon', href: '/favicon.svg' },
      ],
    }
  },

  routeRules: {
    '/': { prerender: true },
    '/imprint': { prerender: true },
    '/privacy': { prerender: true },
  },

  modules: [
    '@nuxt/icon',
    '@vueuse/nuxt',
    '@nuxtjs/device',
    '@nuxt/fonts',
    'nuxt-seo-utils',
    'nuxt-ripple',
  ],

  css : [
    './app/assets/styles/general.css',
    './app/assets/styles/header.css',
    './app/assets/styles/footer.css',
    './app/assets/styles/button.css',
    './app/assets/styles/buttonGroup.css',
    './app/assets/styles/priceCard.css',
    './app/assets/styles/form/textfield.css',
    './app/assets/styles/form/search.css',
    './app/assets/styles/toolbar.css',
    './app/assets/styles/page.css',
    './app/assets/styles/dialog.css',
    './app/assets/styles/landingpage.css',
  ],

  site: {
    url: 'https://pro-papier.de',
    name: 'ProPapier',
  },

  seo: {
    meta: {
      title: 'ProPapier',
      description: '"Bezahlt du zuviel fürs Papier? Vergleiche schnell und unkompliziert die Preise für Toiletten-, Küchen- und andere Papier hier."',
      themeColor: [
        { content: '#18181b', media: '(prefers-color-scheme: dark)' },
        { content: 'white', media: '(prefers-color-scheme: light)' },
      ],
      twitterCreator: '@webfussel',
      twitterSite: '@propapier',
      author: 'webfussel',
      colorScheme: 'dark light',
      applicationName: 'ProPapier',

      // Nuxt SEO Utils already sets the below tags for you
      ogSiteName: 'Propapier',
      ogLocale: 'de_DE',
      ogType: 'website',
      ogUrl: 'https://pro-papier.de',
      ogTitle: 'ProPapier',

      // Other Nuxt SEO modules handles these
      ogImage: 'https://example.com/my-og-image.png',
      robots: 'index, follow',
    }
  },
})